
import router from "./router";
import store from "./store";
import NProgress from "nprogress"; // progress bar
import "nprogress/nprogress.css"; // progress bar style
import { getToken } from "@/utils/auth"; // get token from cookie
import getPageTitle from "@/utils/get-page-title";
import { roterPre } from "@/settings";
import { editFormApi } from "@/api/user";
import { _ } from "core-js";
NProgress.configure({ showSpinner: false }); // NProgress Configuration

const whiteList = [`${roterPre}/login`, "/auth-redirect"]; // no redirect whitelist

router.beforeEach(async (to, from, next) => {
  // start progress bar
  NProgress.start();
  // set page title
  document.title = getPageTitle(to.meta.title);

  // determine whether the user has logged in
  const hasToken = getToken();
  console.log(to, from, "to");

  if (hasToken) {
    if (to.path === `${roterPre}/login`) {
      // if is logged in, redirect to the home page
      next({ path: "/" });
      NProgress.done();
    } else if (to.name === "screenIndex" && from.name != null) {
      window.open(`${roterPre}/data-screen/index`, "_blank");
      return false;
    } else {
      // await store.dispatch('user/getMenus')
      if (from.fullPath === "/" && from.path !== `${roterPre}/login`) {
        editFormApi()
          .then(res => {
            next();
            NProgress.done();
          })
          .catch(res => {
            next();
            NProgress.done();
          });
      } else {
        next();
        NProgress.done();
      }
    }
  } else {
    /* has no token*/
    if (whiteList.indexOf(to.path) !== -1) {
      // in the free login whitelist, go directly
      next();
    } else {
      // other pages that do not have permission to access are redirected to the login page.
      await store.dispatch("user/resetToken");
      next(`${roterPre}/login?redirect=${to.path}`);
      NProgress.done();
    }
  }
});

router.afterEach(() => {
  // finish progress bar
  NProgress.done();
});
